You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ofbiz.apache.org by jl...@apache.org on 2012/04/30 21:52:20 UTC

svn commit: r1332358 - in /ofbiz/branches/release11.04: framework/common/config/ framework/common/webcommon/WEB-INF/ framework/common/webcommon/includes/ framework/common/widget/ framework/images/webapp/images/ framework/webapp/src/org/ofbiz/webapp/con...

Author: jleroux
Date: Mon Apr 30 19:52:19 2012
New Revision: 1332358

URL: http://svn.apache.org/viewvc?rev=1332358&view=rev
Log:
A modified patch from Yashwant Dhakad "ajax autocomplete and dialog during session timeout"

This is only for R11.04 and Yashwant provided a patch. 

What I changed:
* Added <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/> in htmlheader-for-ajax.ftl
* Added a French label an kept those existing but English (improved now)
* Removed some added parts in patch of fieldlookup.js  and selectall.js (like I did in trunk, those related to AJAX_SERVER_REPLY_MSG_REGEXPATTERN, because of not handled UTF8 chars in alert box)
* Added the new spinner.gif and replaced /tomahawk/images/spinner.gif to /images/spinner.gif in tomahawk/css/style.css

Added:
    ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlfooter-for-ajax.ftl   (with props)
    ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlheader-for-ajax.ftl   (with props)
Removed:
    ofbiz/branches/release11.04/themes/tomahawk/webapp/tomahawk/images/spinner.gif
Modified:
    ofbiz/branches/release11.04/framework/common/config/CommonUiLabels.xml
    ofbiz/branches/release11.04/framework/common/webcommon/WEB-INF/common-controller.xml
    ofbiz/branches/release11.04/framework/common/widget/CommonScreens.xml
    ofbiz/branches/release11.04/framework/images/webapp/images/fieldlookup.js
    ofbiz/branches/release11.04/framework/images/webapp/images/selectall.js
    ofbiz/branches/release11.04/framework/images/webapp/images/spinner.gif
    ofbiz/branches/release11.04/framework/webapp/src/org/ofbiz/webapp/control/RequestHandler.java
    ofbiz/branches/release11.04/themes/bizznesstime/webapp/bizznesstime/css/style.css
    ofbiz/branches/release11.04/themes/bluelight/webapp/bluelight/style.css
    ofbiz/branches/release11.04/themes/droppingcrumbs/webapp/droppingcrumbs/css/style.css
    ofbiz/branches/release11.04/themes/flatgrey/webapp/flatgrey/javascript.css
    ofbiz/branches/release11.04/themes/multiflex/webapp/multiflex/style.css
    ofbiz/branches/release11.04/themes/tomahawk/webapp/tomahawk/css/style.css

Modified: ofbiz/branches/release11.04/framework/common/config/CommonUiLabels.xml
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/framework/common/config/CommonUiLabels.xml?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/framework/common/config/CommonUiLabels.xml (original)
+++ ofbiz/branches/release11.04/framework/common/config/CommonUiLabels.xml Mon Apr 30 19:52:19 2012
@@ -7685,6 +7685,13 @@
         <value xml:lang="en">Return Error Service : Returning Error</value>
         <value xml:lang="it">Servizio ha restituito un'errore: errore restituito</value>
     </property>
+    <property key="CommonSessionTimeoutPleaseLogIn">
+        <value xml:lang="en">Your session has expired.  A login is required.  You can refresh the page or save your data to login.</value>
+        <value xml:lang="de">Sie sind nicht mehr angemeldet. Bitte melden Sie sich erneut an.</value>
+        <value xml:lang="es">No está conectado. Por favor, vuelva a conectarse.</value>
+        <value xml:lang="fr">Votre session est terminée. Veuillez vous identifier à nouveau pour utiliser l'application.  Pour vous connecter, vous pouvez actualiser la page, sauvegarder vos données ou utiliser le lien Connexion (ou Déconnexion) en haut à droite.</value>
+        <value xml:lang="vi">Bạn chưa đăng nhập. Vui lòng đăng nhập lại.</value>
+    </property>
     <property key="CommonSet">
         <value xml:lang="ar">وضع</value>
         <value xml:lang="de">Setzen</value>

Modified: ofbiz/branches/release11.04/framework/common/webcommon/WEB-INF/common-controller.xml
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/framework/common/webcommon/WEB-INF/common-controller.xml?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/framework/common/webcommon/WEB-INF/common-controller.xml (original)
+++ ofbiz/branches/release11.04/framework/common/webcommon/WEB-INF/common-controller.xml Mon Apr 30 19:52:19 2012
@@ -76,6 +76,13 @@ under the License.
         <response name="success" type="view" value="main"/>
         <response name="error" type="view" value="login"/>
     </request-map>
+    <request-map uri="ajaxCheckLogin" edit="false">
+        <description>Verify a user is logged in.</description>
+        <security https="true" auth="false"/>
+        <event type="java" path="org.ofbiz.webapp.control.LoginWorker" invoke="checkLogin"/>
+        <response name="success" type="view" value="main"/>
+        <response name="error" type="view" value="ajaxLogin"/>
+    </request-map>
     <request-map uri="login">
         <security https="true" auth="false"/>
         <event type="java" path="org.ofbiz.webapp.control.LoginWorker" invoke="login"/>
@@ -250,6 +257,7 @@ under the License.
     <view-map name="error" page="/error/error.jsp"/>
     <view-map name="main" type="none"/>
     <view-map name="login" type="screen" page="component://common/widget/CommonScreens.xml#login"/>
+    <view-map name="ajaxLogin" type="screen" page="component://common/widget/CommonScreens.xml#ajaxNotLoggedIn"/>
     <view-map name="requirePasswordChange" type="screen" page="component://common/widget/CommonScreens.xml#requirePasswordChange"/>
     <view-map name="forgotPassword" type="screen" page="component://common/widget/CommonScreens.xml#forgotPassword"/>
     <view-map name="EventMessages" type="screen" page="component://common/widget/CommonScreens.xml#EventMessages"/>

Added: ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlfooter-for-ajax.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlfooter-for-ajax.ftl?rev=1332358&view=auto
==============================================================================
--- ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlfooter-for-ajax.ftl (added)
+++ ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlfooter-for-ajax.ftl Mon Apr 30 19:52:19 2012
@@ -0,0 +1,21 @@
+<#--
+Licensed to the Apache Software Foundation (ASF) under one
+or more contributor license agreements.  See the NOTICE file
+distributed with this work for additional information
+regarding copyright ownership.  The ASF licenses this file
+to you under the Apache License, Version 2.0 (the
+"License"); you may not use this file except in compliance
+with the License.  You may obtain a copy of the License at
+
+http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing,
+software distributed under the License is distributed on an
+"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+KIND, either express or implied.  See the License for the
+specific language governing permissions and limitations
+under the License.
+-->
+
+</body>
+</html>

Propchange: ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlfooter-for-ajax.ftl
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlfooter-for-ajax.ftl
------------------------------------------------------------------------------
    svn:keywords = Date Rev Author URL Id

Propchange: ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlfooter-for-ajax.ftl
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlheader-for-ajax.ftl
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlheader-for-ajax.ftl?rev=1332358&view=auto
==============================================================================
--- ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlheader-for-ajax.ftl (added)
+++ ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlheader-for-ajax.ftl Mon Apr 30 19:52:19 2012
@@ -0,0 +1,29 @@
+<#--
+Licensed to the Apache Software Foundation (ASF) under one
+or more contributor license agreements.  See the NOTICE file
+distributed with this work for additional information
+regarding copyright ownership.  The ASF licenses this file
+to you under the Apache License, Version 2.0 (the
+"License"); you may not use this file except in compliance
+with the License.  You may obtain a copy of the License at
+
+http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing,
+software distributed under the License is distributed on an
+"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+KIND, either express or implied.  See the License for the
+specific language governing permissions and limitations
+under the License.
+-->
+<#assign docLangAttr = locale.toString()?replace("_", "-")>
+<#assign langDir = "ltr">
+<#if "ar.iw"?contains(docLangAttr?substring(0, 2))>
+    <#assign langDir = "rtl">
+</#if>
+<html lang="${docLangAttr}" dir="${langDir}" xmlns="http://www.w3.org/1999/xhtml">
+<head>
+    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
+</head>
+<body>
+<#--<br class="clear" />-->

Propchange: ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlheader-for-ajax.ftl
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlheader-for-ajax.ftl
------------------------------------------------------------------------------
    svn:keywords = Date Rev Author URL Id

Propchange: ofbiz/branches/release11.04/framework/common/webcommon/includes/htmlheader-for-ajax.ftl
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Modified: ofbiz/branches/release11.04/framework/common/widget/CommonScreens.xml
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/framework/common/widget/CommonScreens.xml?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/framework/common/widget/CommonScreens.xml (original)
+++ ofbiz/branches/release11.04/framework/common/widget/CommonScreens.xml Mon Apr 30 19:52:19 2012
@@ -87,6 +87,27 @@ under the License.
             </widgets>
         </section>
     </screen>
+    <!-- decorator used in creating a response to an ajax request -->
+    <screen name="AjaxGlobalDecorator">
+        <section>
+            <actions>
+                <property-map resource="CommonUiLabels" map-name="uiLabelMap" global="true" />
+            </actions>
+            <widgets>
+                <platform-specific>
+                    <html>
+                        <html-template location="component://common/webcommon/includes/htmlheader-for-ajax.ftl" />
+                    </html>
+                </platform-specific>
+                <decorator-section-include name="body" />
+                <platform-specific>
+                    <html>
+                        <html-template location="component://common/webcommon/includes/htmlfooter-for-ajax.ftl" />
+                    </html>
+                </platform-specific>
+            </widgets>
+        </section>
+    </screen>
     <!--
         The following screen is used to generate Ajax list of options for autocomplete fields
     -->
@@ -96,7 +117,13 @@ under the License.
                 <set field="autocompleteOptions" from-field="parameters.autocompleteOptions"/>
             </actions>
             <widgets>
-                <platform-specific><html><html-template location="component://common/webcommon/includes/ajaxAutocompleteOptions.ftl"/></html></platform-specific>
+                <decorator-screen name="AjaxGlobalDecorator">
+                    <decorator-section name="body">
+                        <platform-specific>
+                            <html><html-template location="component://common/webcommon/includes/ajaxAutocompleteOptions.ftl" /></html>
+                        </platform-specific>
+                    </decorator-section>
+                </decorator-screen>
             </widgets>
         </section>
     </screen>
@@ -332,7 +359,15 @@ under the License.
                         <script location="component://common/webcommon/WEB-INF/actions/includes/FindAutocompleteOptions.groovy"/>
                     </actions>
                     <widgets>
-                        <platform-specific><html><html-template location="component://common/webcommon/includes/ajaxAutocompleteOptions.ftl"/></html></platform-specific>
+                        <decorator-screen name="AjaxGlobalDecorator">
+                            <decorator-section name="body">
+                                <platform-specific>
+                                    <html>
+                                        <html-template location="component://common/webcommon/includes/ajaxAutocompleteOptions.ftl" />
+                                    </html>
+                                </platform-specific>
+                            </decorator-section>
+                        </decorator-screen>
                     </widgets>
                 </section>
             </fail-widgets>
@@ -543,6 +578,18 @@ under the License.
         </section>
     </screen>
 
+    <screen name="ajaxNotLoggedIn">
+        <section>
+            <widgets>
+                <decorator-screen name="AjaxGlobalDecorator">
+                    <decorator-section name="body">
+                        <label style="message" text="${uiLabelMap.CommonSessionTimeoutPleaseLogIn}"/>
+                    </decorator-section>
+                </decorator-screen>
+            </widgets>
+        </section>
+    </screen>
+
     <screen name="viewBlocked">
         <section>
             <actions>

Modified: ofbiz/branches/release11.04/framework/images/webapp/images/fieldlookup.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/framework/images/webapp/images/fieldlookup.js?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/framework/images/webapp/images/selectall.js (original)
+++ ofbiz/branches/release11.04/framework/images/webapp/images/selectall.js Mon Apr 30 19:52:19 2012
@@ -20,6 +20,9 @@
 //Define global variable to store last auto-completer request object (jqXHR).
 var LAST_AUTOCOMP_REF = null;
 
+//default ajax request timeout in milliseconds
+var AJAX_REQUEST_TIMEOUT = 5000;
+
 // Check Box Select/Toggle Functions for Select/Toggle All
 
 function toggle(e) {
@@ -430,9 +433,9 @@ function ajaxAutoCompleter(areaCsvString
                         LAST_AUTOCOMP_REF= jqXHR;
                     },
                     success: function(data) {
-                    	// reset the autocomp field
-                    	autocomp = undefined;
-                    	
+                    // reset the autocomp field
+                        autocomp = undefined;
+
                         //update the result div
                         jQuery("#" + div + "_auto").html(data);
                         if (typeof autocomp != 'undefined') {
@@ -441,9 +444,15 @@ function ajaxAutoCompleter(areaCsvString
                             })
                             // autocomp is the JSON Object which will be used for the autocomplete box
                             response(autocomp);
+                        } else {
+                            response([]);
                         }
-                    }
-                })
+                   },
+                    error: function(xhr, reason, exception) {
+                        //TODO ... need to localize the following error message.
+                        alert("An error occurred while communicating with the server:\n\n\nreason=" + reason + "\n\nexception=" + exception);
+                    },
+                });
             },
             select: function(event, ui){
                 //jQuery("#" + areaArray[0]).html(ui.item);

Modified: ofbiz/branches/release11.04/framework/images/webapp/images/spinner.gif
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/framework/images/webapp/images/spinner.gif?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
Binary files - no diff available.

Modified: ofbiz/branches/release11.04/framework/webapp/src/org/ofbiz/webapp/control/RequestHandler.java
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/framework/webapp/src/org/ofbiz/webapp/control/RequestHandler.java?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/framework/webapp/src/org/ofbiz/webapp/control/RequestHandler.java (original)
+++ ofbiz/branches/release11.04/framework/webapp/src/org/ofbiz/webapp/control/RequestHandler.java Mon Apr 30 19:52:19 2012
@@ -359,7 +359,12 @@ public class RequestHandler {
             if (!"success".equalsIgnoreCase(checkLoginReturnString)) {
                 // previous URL already saved by event, so just do as the return says...
                 eventReturn = checkLoginReturnString;
-                requestMap = requestMapMap.get("checkLogin");
+             // if the request is an ajax request we don't want to return the default login check
+                if (!"XMLHttpRequest".equals(request.getHeader("X-Requested-With"))) {
+                    requestMap = requestMapMap.get("checkLogin");
+                } else {
+                    requestMap = requestMapMap.get("ajaxCheckLogin");
+                }
             }
         }
 

Modified: ofbiz/branches/release11.04/themes/bizznesstime/webapp/bizznesstime/css/style.css
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/themes/bizznesstime/webapp/bizznesstime/css/style.css?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/themes/bizznesstime/webapp/bizznesstime/css/style.css (original)
+++ ofbiz/branches/release11.04/themes/bizznesstime/webapp/bizznesstime/css/style.css Mon Apr 30 19:52:19 2012
@@ -1476,8 +1476,9 @@ z-index:50000;
 position:absolute;
 }
 #wait-spinner-image {
-height:21px;
-width:56px;
+height:45px;
+width:45px;
+background-repeat: no-repeat;
 background-image:url(/images/spinner.gif);
 }
 

Modified: ofbiz/branches/release11.04/themes/bluelight/webapp/bluelight/style.css
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/themes/bluelight/webapp/bluelight/style.css?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/themes/bluelight/webapp/bluelight/style.css (original)
+++ ofbiz/branches/release11.04/themes/bluelight/webapp/bluelight/style.css Mon Apr 30 19:52:19 2012
@@ -2047,8 +2047,9 @@ position:absolute;
     padding-top: 4px;
 }
 #wait-spinner-image {
-height:21px;
-width:56px;
+height:45px;
+width:45px;
+background-repeat: no-repeat;
 background-image:url(/images/spinner.gif);
 }
 

Modified: ofbiz/branches/release11.04/themes/droppingcrumbs/webapp/droppingcrumbs/css/style.css
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/themes/droppingcrumbs/webapp/droppingcrumbs/css/style.css?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/themes/droppingcrumbs/webapp/droppingcrumbs/css/style.css (original)
+++ ofbiz/branches/release11.04/themes/droppingcrumbs/webapp/droppingcrumbs/css/style.css Mon Apr 30 19:52:19 2012
@@ -2029,8 +2029,9 @@ z-index:50000;
 position:absolute;
 }
 #wait-spinner-image {
-height:21px;
-width:56px;
+height:45px;
+width:45px;
+background-repeat: no-repeat;
 background-image:url(/images/spinner.gif);
 }
 .wait-spinner div {

Modified: ofbiz/branches/release11.04/themes/flatgrey/webapp/flatgrey/javascript.css
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/themes/flatgrey/webapp/flatgrey/javascript.css?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/themes/flatgrey/webapp/flatgrey/javascript.css (original)
+++ ofbiz/branches/release11.04/themes/flatgrey/webapp/flatgrey/javascript.css Mon Apr 30 19:52:19 2012
@@ -27,8 +27,9 @@ position:absolute;
 }
 
 #wait-spinner-image {
-height:21px;
-width:56px;
+height:45px;
+width:45px;
+background-repeat: no-repeat;
 background-image:url(/images/spinner.gif);
 }
 
@@ -708,10 +709,11 @@ button.ui-button::-moz-focus-inner { bor
 background: url(images/cal.gif) no-repeat !important;
 display: inline-block;
 border: none;
-vertical-align:center;
-margin-top:3px;
-margin-left: 6px;
-height:22px;
+vertical-align: middle;
+/*wt;begin/end*/
+margin: 2px 2px 2px 2px;
+height: 18px;
+width: 18px;
 }
 
 /* css for timepicker */

Modified: ofbiz/branches/release11.04/themes/multiflex/webapp/multiflex/style.css
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/themes/multiflex/webapp/multiflex/style.css?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/themes/multiflex/webapp/multiflex/style.css (original)
+++ ofbiz/branches/release11.04/themes/multiflex/webapp/multiflex/style.css Mon Apr 30 19:52:19 2012
@@ -2745,8 +2745,9 @@ z-index:50000;
 position:absolute;
 }
 #wait-spinner-image {
-height:21px;
-width:56px;
+height:45px;
+width:45px;
+background-repeat: no-repeat;
 background-image:url(/images/spinner.gif);
 }
 

Modified: ofbiz/branches/release11.04/themes/tomahawk/webapp/tomahawk/css/style.css
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/themes/tomahawk/webapp/tomahawk/css/style.css?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================
--- ofbiz/branches/release11.04/themes/tomahawk/webapp/tomahawk/css/style.css (original)
+++ ofbiz/branches/release11.04/themes/tomahawk/webapp/tomahawk/css/style.css Mon Apr 30 19:52:19 2012
@@ -2416,9 +2416,10 @@ z-index:50000;
 position:absolute;
 }
 #wait-spinner-image {
-height:21px;
-width:56px;
-background-image:url(/tomahawk/images/spinner.gif);
+height:45px;
+width:45px;
+background-repeat: no-repeat;
+background-image:url(/images/spinner.gif);
 }
 .wait-spinner div {
     padding-top: 4px;
--- ofbiz/branches/release11.04/framework/images/webapp/images/fieldlookup.js (original)
+++ ofbiz/branches/release11.04/framework/images/webapp/images/fieldlookup.js Mon Apr 30 19:52:19 2012
@@ -185,9 +185,8 @@ function ConstructLookup(requestUrl, inp
     // add the presentation attribute to the request url to let the request know which decorator should be loaded
     if(!presentation) {
       var presentation = "layer"
-    }    
-    requestUrl = getViewNameWithSeparator(requestUrl) + "presentation=" + presentation;
-    
+    }
+
     // create Link Element with unique Key
     var lookupId = GLOBAL_LOOKUP_REF.createNextKey();
     var inputBox = document.getElementById(inputFieldId);
@@ -251,35 +250,59 @@ function ConstructLookup(requestUrl, inp
         position: positioning,
         draggable: true,
         resizeable: true,
-        open: function() {
-            var requestUrlAndArgs = requestUrl;
+        open: function(event,ui) {
+            waitSpinnerShow();
+            jQuery("#" + lookupId).empty();
+
+            var queryArgs = "presentation=" + presentation;
             if (typeof args == "object" && jQuery.isArray(args)) {
                 for (var i = 0; i < args.length; i++) {
-                    requestUrlAndArgs += "&parm" + i + "=" + jQuery(args[i]).val();
+                    queryArgs += "&parm" + i + "=" + jQuery(args[i]).val();
                 }
             }
-            jQuery("#" + lookupId).load(requestUrlAndArgs, function(data){ 
-                lookupFormAction = jQuery("#" + lookupId + " form:first").attr("action");
-                modifySubmitButton(lookupId);
-                jQuery("#" + lookupId).bind("keypress", lookup_onKeyEnter);
-                // set up the window chaining
-                // if the ACTIVATED_LOOKUP var is set there have to be more than one lookup,
-                // before registrating the new lookup we store the id of the old lookup in the
-                // preLookup variable of the new lookup object. I.e. lookup_1 calls lookup_8, the lookup_8
-                // object need a reference to lookup_1, this reference is set here
-                var prevLookup = null
-                if (ACTIVATED_LOOKUP) {
-                    prevLookup = GLOBAL_LOOKUP_REF.getReference(ACTIVATED_LOOKUP).lookupId;
-                }
-                identifyLookup(lookupId);
-                
-                if (prevLookup) {
-                    GLOBAL_LOOKUP_REF.getReference(ACTIVATED_LOOKUP).prevLookup = prevLookup;
-                }
+        jQuery.ajax({
+                type: "post",
+                url: requestUrl,
+                data: queryArgs,
+                timeout: AJAX_REQUEST_TIMEOUT,
+                cache: false,
+                dataFilter: function(data, dataType) {
+                    waitSpinnerHide();
+                    return data;
+                },
+                success: function(data) {
+                    jQuery("#" + lookupId).html(data);
+                    
+                    lookupFormAction = jQuery("#" + lookupId + " form:first").attr("action");
+                    modifySubmitButton(lookupId);
+                    jQuery("#" + lookupId).bind("keypress", lookup_onKeyEnter);
+                    // set up the window chaining
+                    // if the ACTIVATED_LOOKUP var is set there have to be more than one lookup,
+                    // before registrating the new lookup we store the id of the old lookup in the
+                    // preLookup variable of the new lookup object. I.e. lookup_1 calls lookup_8, the lookup_8
+                    // object need a reference to lookup_1, this reference is set here
+                    var prevLookup = null
+                    if (ACTIVATED_LOOKUP) {
+                        prevLookup = GLOBAL_LOOKUP_REF.getReference(ACTIVATED_LOOKUP).lookupId;
+                    }
+                    identifyLookup(lookupId);
+                    
+                    if (prevLookup) {
+                        GLOBAL_LOOKUP_REF.getReference(ACTIVATED_LOOKUP).prevLookup = prevLookup;
+                    }
+                },
+                error: function(xhr, reason, exception) {
+                    //TODO ... need to localize the following error message.
+                    alert("An error occurred while communicating with the server:\n\n\nreason=" + reason + "\n\nexception=" + exception);
+                    location.reload(true);
+                },
             });
         },
         close: function() {
             jQuery("#" + lookupId).unbind("keypress", lookup_onKeyEnter);
+
+            waitSpinnerHide();
+
             //when the window is closed the prev Lookup get the focus (if exists)
             if (ACTIVATED_LOOKUP) {
                 var prevLookup = GLOBAL_LOOKUP_REF.getReference(ACTIVATED_LOOKUP).prevLookup;

Modified: ofbiz/branches/release11.04/framework/images/webapp/images/selectall.js
URL: http://svn.apache.org/viewvc/ofbiz/branches/release11.04/framework/images/webapp/images/selectall.js?rev=1332358&r1=1332357&r2=1332358&view=diff
==============================================================================